<?php
namespace Planejamento\Entities;

class Recepadr extends Base\Recepadr
{
    /**
     * Atualiza as quantidades da receita padrão
     *
     * @param String $nrorg           Organização
     * @param String $cdprato         Prato
     * @param String $cdfilauxprat    Fila de prato
     * @param String $cdproduto       Produto
     * @param String $qtprodprat      Quantidade
     * @param String $qtbrutapr       Quantidade Requerida
     * @param String $qtbrutaprunr    Quantidade Bruta
     * @param String $qtunidestpr     Quantidade líquida do produto na unidade de estoque
     * @param String $qtcalcnutrpr    Quantidade de Cálculo de Nutrientes
     * @param String $qtcomplprodpadr Quantidade Complementar
     *
     * @throws \Exception
     * @return null
     */
    public static function atualizaQtdeReceitaPadrao(
        $produtoReceita, $qtprodprat, $qtbrutapr,
        $qtbrutaprunr, $qtunidestpr, $qtcalcnutrpr, $qtcomplprodpadr
    ) {
        try {
            $produtoReceita->setQtbrutapr($qtbrutapr);
            $produtoReceita->setQtbrutaprunr($qtbrutaprunr);
            $produtoReceita->setQtcalcnutrpr($qtcalcnutrpr);
            $produtoReceita->setQtcomplprodpadr($qtcomplprodpadr);
            $produtoReceita->setQtprodprat($qtprodprat);
            $produtoReceita->setQtunidestpr($qtunidestpr);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Retorna os produtos da receita padrão
     *
     * @param String $nrorg        Organização
     * @param String $cdprato      Prato
     * @param String $cdfilauxprat Fila de prato
     *
     * @return mixed
     * @throws \Exception
     */
    public static function getProdutosReceitaPadrao($nrorg, $cdprato, $cdfilauxprat)
    {
        try {
            /** @var Recepadr $recPadrao Receita Padrão */
            $receitaPadrao = Recepadr::getObjectsByWhere(
                'NRORG = ? AND CDPRATO = ? AND CDFILAUXPRAT = ?',
                array($nrorg, $cdprato, $cdfilauxprat)
            );

            return $receitaPadrao ;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Retorna o produto da receita padrão
     *
     * @param String $nrorg        Organização
     * @param String $cdprato      Prato
     * @param String $cdfilauxprat Fila de prato
     * @param String $cdproduto    Produto
     *
     * @throws \Exception
     * @return mixed
     */
    public static function getProdutoReceitaPadrao($nrorg, $cdprato,
        $cdfilauxprat, $cdproduto)
    {
        try {
            /** @var Recepadr $receitaPadrao Receita Padrão */
            $receitaPadrao = Recepadr::getObjectByWhere(
                'NRORG = ? AND CDPRATO = ? AND CDFILAUXPRAT = ? AND CDPRODUTO = ?',
                array($nrorg, $cdprato, $cdfilauxprat, $cdproduto)
            );

            return $receitaPadrao;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insereReceitaPadrao($cdprato,$cdfilauxprat,$quantidade,$cdproduto,$unidade,$idtpreqprodpadr,$idutcompentdirp,$ativo,$nrorg,$dtinclusao,$dtultatu,$cdoperador){
        $this->setCdprato($cdprato);
        $this->setCdfilauxprat($cdfilauxprat);
        $this->setQtprodprat($quantidade);
        $this->setCdproduto($cdproduto);
        $this->setIdtpreqprodpadr($idtpreqprodpadr);
        $this->setIdutcompentdirp($idutcompentdirp);
        $this->setSgunidade($unidade);
        $this->setIdativo($ativo);

        //Campos auditoria
        $this->setCdoperinclusao($cdoperador);
        $this->setDtinclusao($dtinclusao);
        $this->setDtultatu($dtultatu);
        $this->setNrorginclusao($nrorg);
        $this->setNrorg($nrorg);

        $this->persist();
    }
}